@@ -66,9 +66,10 @@ fn copy_prebuilt_include_file(
     build_targets: &BuildTargets,
     root_output: &Path,
 ) -> anyhow::Result<()> {
-    ws.config()
-        .shell()
-        .status("Populating", "uninstalled header directory")?;
+    let mut shell = ws.config().shell();
+    shell.status("Populating", "uninstalled header directory")?;
+    let path = &format!("PKG_CONFIG_PATH=\"{}\"", root_output.display());
+    shell.verbose(move |s| s.note(path))?;
     for (from, to) in build_targets.extra.include.iter() {
         let to = root_output.join("include").join(to);
         create_dir_all(to.parent().unwrap())?;
@@ -410,9 +411,10 @@ pub struct LibraryCApiConfig {
     pub rustflags: Vec<String>,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct InstallCApiConfig {
     pub include: Vec<InstallTarget>,
+    pub data: Vec<InstallTarget>,
 }
 
 #[derive(Debug)]
@@ -678,28 +680,63 @@ fn load_manifest_capi_config(pkg: &Package) -> anyhow::Result<CApiConfig> {
         InstallTarget::Asset(default_legacy_asset_include),
         InstallTarget::Generated(default_generated_include),
     ];
+    let mut data_targets = Vec::new();
+
+    let mut data_subdirectory = name.clone();
+
+    fn custom_install_target_paths(
+        root: &toml::Value,
+        subdirectory: &str,
+        targets: &mut Vec<InstallTarget>,
+    ) -> anyhow::Result<()> {
+        if let Some(assets) = root.get("asset").and_then(|v| v.as_array()) {
+            for asset in assets {
+                let target_paths = InstallTargetPaths::from_value(asset, subdirectory)?;
+                targets.push(InstallTarget::Asset(target_paths));
+            }
+        }
+
+        if let Some(generated) = root.get("generated").and_then(|v| v.as_array()) {
+            for gen in generated {
+                let target_paths = InstallTargetPaths::from_value(gen, subdirectory)?;
+                targets.push(InstallTarget::Generated(target_paths));
+            }
+        }
+
+        Ok(())
+    }
 
     let install = capi.and_then(|v| v.get("install"));
     if let Some(install) = install {
         if let Some(includes) = install.get("include") {
-            if let Some(assets) = includes.get("asset").and_then(|v| v.as_array()) {
-                for asset in assets {
-                    let target_paths = InstallTargetPaths::from_value(asset, &header.subdirectory)?;
-                    include_targets.push(InstallTarget::Asset(target_paths));
-                }
-            }
-
-            if let Some(generated) = includes.get("generated").and_then(|v| v.as_array()) {
-                for gen in generated {
-                    let target_paths = InstallTargetPaths::from_value(gen, &header.subdirectory)?;
-                    include_targets.push(InstallTarget::Generated(target_paths));
-                }
+            custom_install_target_paths(includes, &header.subdirectory, &mut include_targets)?;
+        }
+        if let Some(data) = install.get("data") {
+            if let Some(subdir) = data.get("subdirectory").and_then(|v| v.as_str()) {
+                data_subdirectory = String::from(subdir);
             }
+            custom_install_target_paths(data, &data_subdirectory, &mut data_targets)?;
         }
     }
 
+    let default_assets_data = InstallTargetPaths {
+        from: "assets/capi/share/**/*".to_string(),
+        to: data_subdirectory.clone(),
+    };
+
+    let default_generated_data = InstallTargetPaths {
+        from: "capi/share/**/*".to_string(),
+        to: data_subdirectory,
+    };
+
+    data_targets.extend([
+        InstallTarget::Asset(default_assets_data),
+        InstallTarget::Generated(default_generated_data),
+    ]);
+
     let install = InstallCApiConfig {
         include: include_targets,
+        data: data_targets,
     };
 
     Ok(CApiConfig {
