@@ -143,7 +143,7 @@ impl PkgConfig {
     pub(crate) fn uninstalled(&self, output: &Path) -> Self {
         let mut uninstalled = self.clone();
         uninstalled.prefix = output.to_path_buf();
-        uninstalled.includedir = "${prefix}".into();
+        uninstalled.includedir = "${prefix}/include".into();
         uninstalled.libdir = "${prefix}".into();
         // First libs item is the search path
         uninstalled.libs[0] = "-L${prefix}".into();
@@ -212,7 +212,8 @@ Cflags: {}",
             canonicalize(&self.libdir),
             canonicalize(&self.includedir),
             self.name,
-            self.description,
+            // avoid endlines
+            self.description.replace("\n", " "),
             self.version,
             self.libs.join(" "),
             self.cflags.join(" "),
@@ -287,9 +288,7 @@ mod test {
                     versioning: true,
                     rustflags: Vec::default(),
                 },
-                install: crate::build::InstallCApiConfig {
-                    include: Vec::new(),
-                },
+                install: Default::default(),
             },
         );
         pkg.add_lib("-lbar").add_cflag("-DFOO");
